@@ -1,7 +1,8 @@
 /*******************************************************************************
    This file is part of SecureSkat.
 
- Copyright (C) 2002, 2003, 2004, 2006, 2007  Heiko Stamer <stamer@gaos.org>
+ Copyright (C) 2002, 2003, 2004, 2006, 2007
+                                       2017  Heiko Stamer <HeikoStamer@gmx.net>
 
    SecureSkat is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -126,17 +127,29 @@ void encrypt_secret_key
 void get_secret_key
 	(const std::string &filename, TMCG_SecretKey &sec, std::string &prefix)
 {
-	assert(gcry_md_get_algo_dlen(TMCG_GCRY_MD_ALGO));
-	assert(gcry_md_get_algo_dlen(TMCG_GCRY_MD_ALGO) >= 
-		gcry_cipher_get_algo_keylen(GCRY_CIPHER_BLOWFISH));
-	
 	std::string key_str;
 	std::ostringstream ost;
 	datum key, data;
+
+	// check libgcrypt algorithms
+	if (!gcry_md_get_algo_dlen(TMCG_GCRY_MD_ALGO))
+	{
+		std::cerr << "SecureSkat_pki::get_secret_key: gcry_md_get_algo_dlen() failed" << std::endl;
+		exit(-1);
+	}
+	if (!gcry_cipher_get_algo_keylen(GCRY_CIPHER_BLOWFISH))
+	{
+		std::cerr << "SecureSkat_pki::get_secret_key: gcry_cipher_get_algo_keylen() failed" << std::endl;
+		exit(-1);
+	}
+	if (gcry_md_get_algo_dlen(TMCG_GCRY_MD_ALGO) < gcry_cipher_get_algo_keylen(GCRY_CIPHER_BLOWFISH))
+	{
+		std::cerr << "SecureSkat_pki::get_secret_key: output length of TMCG_GCRY_MD_ALGO too small" << std::endl;
+		exit(-1);	
+	}
 	
 	// open GDBM file where the secret key is stored
-	GDBM_FILE sec_db = 
-		gdbm_open((char*)filename.c_str(), 0, GDBM_WRCREAT, S_IRUSR | S_IWUSR, 0);
+	GDBM_FILE sec_db = gdbm_open((char*)filename.c_str(), 0, GDBM_WRCREAT, S_IRUSR | S_IWUSR, 0);
 	if (sec_db != NULL)
 	{
 		// key is stored at the first entry of the GDBM file
@@ -151,8 +164,7 @@ void get_secret_key
 			// check whether the entry is encrypted
 			std::string pass_phrase = "";
 			if (memcmp(data.dptr, "sec", 3))
-			    pass_phrase =
-				get_passphrase(_("Enter the pass phrase to unlock your key"));
+			    pass_phrase = get_passphrase(_("Enter the pass phrase to unlock your key"));
 						
 			// decrypt entry with a pass phrase supplied by the user
 			if (pass_phrase != "")
@@ -164,14 +176,12 @@ void get_secret_key
 				// compute T_1 = hash(password || salt)
 				unsigned char *T_i = new unsigned char[dlen];
 				std::string input = pass_phrase + key_str;
-				gcry_md_hash_buffer(TMCG_GCRY_MD_ALGO, T_i,
-					input.c_str(), input.length());
+				gcry_md_hash_buffer(TMCG_GCRY_MD_ALGO, T_i, input.c_str(), input.length());
 				// use PBKDF1 with iteration count = 7000
 				// compute T_2, ..., T_7000
 				for (size_t i = 1; i < 7000; i++)
 				{
-				    gcry_md_hash_buffer(TMCG_GCRY_MD_ALGO, pass_digest, 
-					T_i, dlen);
+				    gcry_md_hash_buffer(TMCG_GCRY_MD_ALGO, pass_digest, T_i, dlen);
 				    memcpy(T_i, pass_digest, dlen);
 				}
 				decrypt_secret_key(data, pass_digest);
@@ -196,8 +206,7 @@ void get_secret_key
 			std::getline(std::cin, name);
 			std::cout << _("Your electronic mail address") << ": ";
 			std::getline(std::cin, email);
-			std::cerr << _("Creating your key.") << " " <<
-				_("Please wait") << std::flush;
+			std::cerr << _("Creating your key.") << " " << _("Please wait") << "... " << std::endl << std::flush;
 			while (1)
 			{
 				// create a 1024-bit non-NIZK TMCG key
@@ -222,19 +231,15 @@ void get_secret_key
 			std::string pass_phrase, pass_retyped;
 			do
 			{
-				pass_phrase = 
-					get_passphrase(_("Enter a pass phrase to protect your secret key"));
+				pass_phrase = get_passphrase(_("Enter a pass phrase to protect your secret key"));
 				if (pass_phrase == "")
 				{
-					std::cerr << _("Empty pass phrase. Key protection disabled!") <<
-						std::endl;
+					std::cerr << _("Empty pass phrase. Key protection disabled!") << std::endl;
 					break;
 				}
-				pass_retyped =
-					get_passphrase(_("Repeat your pass phrase"));
+				pass_retyped = get_passphrase(_("Repeat your pass phrase"));
 				if (pass_phrase != pass_retyped)
-					std::cerr << _("Your pass phrases differ.") << " " <<
-						_("Please repeat carefully!") << std::endl;
+					std::cerr << _("Your pass phrases differ.") << " " << _("Please repeat carefully!") << std::endl;
 			}
 			while (pass_phrase != pass_retyped);
 			
@@ -246,14 +251,12 @@ void get_secret_key
 				// compute T_1 = hash(password || salt)
 				unsigned char *T_i = new unsigned char[dlen];
 				std::string input = pass_phrase + keyid;
-				gcry_md_hash_buffer(TMCG_GCRY_MD_ALGO, T_i, 
-				    input.c_str(), input.length());
+				gcry_md_hash_buffer(TMCG_GCRY_MD_ALGO, T_i, input.c_str(), input.length());
 				// use PBKDF1 with iteration count = 7000
 				// compute T_2, ..., T_7000
 				for (size_t i = 1; i < 7000; i++)
 				{
-					gcry_md_hash_buffer(TMCG_GCRY_MD_ALGO, pass_digest, 
-						T_i, dlen);
+					gcry_md_hash_buffer(TMCG_GCRY_MD_ALGO, pass_digest, T_i, dlen);
 					memcpy(T_i, pass_digest, dlen);
 				}
 				delete [] T_i;
@@ -263,30 +266,26 @@ void get_secret_key
 			
 			// store (encrypted) entry in GDBM file at the first position
 			gdbm_store(sec_db, key, data, GDBM_INSERT);
-			std::cout << _("PKI: cryptographic key") << " \"" << keyid <<
-				"\" " << _("created and stored") << std::endl;
+			std::cout << _("PKI: cryptographic key") << " \"" << keyid << "\" " << _("created and stored") << std::endl;
 		}
 		gdbm_close(sec_db);
 	}
 	else
 	{
-		std::cerr << _("GDBM ERROR") << ": " << gdbm_strerror(gdbm_errno) <<
-			std::endl;
+		std::cerr << _("GDBM ERROR") << ": " << gdbm_strerror(gdbm_errno) << std::endl;
 		perror("SecureSkat_pki::get_secret_key (gdbm_open)");
 		exit(-1);
 	}
 	
 	if (!sec.import(ost.str()))
 	{
-		std::cerr << _("PKI ERROR: secret key corrupted") << 
-			" [" << key_str << "]" << std::endl;
+		std::cerr << _("PKI ERROR: secret key corrupted") << " [" << key_str << "]" << std::endl;
 		exit(-1);
 	}
 	else
 	{
 #ifndef NDEBUG
-		std::cout << _("PKI: secret key successfully loaded") << 
-			" [" << key_str << "]" << std::endl;
+		std::cout << _("PKI: secret key successfully loaded") << " [" << key_str << "]" << std::endl;
 #endif
 	}
 	
@@ -305,8 +304,7 @@ void get_public_keys
 	(const std::string &filename, std::map<std::string, TMCG_PublicKey> &keys)
 {
 	datum key, nextkey, data;
-	GDBM_FILE pub_db = 
-		gdbm_open((char*)filename.c_str(), 0, GDBM_WRCREAT, S_IRUSR | S_IWUSR, 0);
+	GDBM_FILE pub_db = gdbm_open((char*)filename.c_str(), 0, GDBM_WRCREAT, S_IRUSR | S_IWUSR, 0);
 	if (pub_db != NULL)
 	{
 		key = gdbm_firstkey(pub_db);
@@ -317,8 +315,7 @@ void get_public_keys
 			if (pkey.import(data.dptr))
 				keys[key.dptr] = pkey;
 			else
-				std::cerr << _("PKI ERROR: public key corrupted") <<
-					" [" << key.dptr << "]" << std::endl;
+				std::cerr << _("PKI ERROR: public key corrupted") << " [" << key.dptr << "]" << std::endl;
 			nextkey = gdbm_nextkey(pub_db, key);
 			free(data.dptr);
 			free(key.dptr);
@@ -328,8 +325,7 @@ void get_public_keys
 	}
 	else
 	{
-		std::cerr << _("GDBM ERROR") << ": " << gdbm_strerror(gdbm_errno) <<
-			std::endl;
+		std::cerr << _("GDBM ERROR") << ": " << gdbm_strerror(gdbm_errno) << std::endl;
 		perror("SecureSkat_pki::get_public_keys (gdbm_open)");
 		exit(-1);
 	}
@@ -340,8 +336,7 @@ void set_public_keys
 	const std::map<std::string, TMCG_PublicKey> &keys)
 {
 	datum key, data;
-	GDBM_FILE pub_db = 
-		gdbm_open((char*)filename.c_str(), 0, GDBM_WRCREAT, S_IRUSR | S_IWUSR, 0);
+	GDBM_FILE pub_db = gdbm_open((char*)filename.c_str(), 0, GDBM_WRCREAT, S_IRUSR | S_IWUSR, 0);
 	if (pub_db != NULL)
 	{
 		for (std::map<std::string, TMCG_PublicKey>::const_iterator
@@ -363,8 +358,7 @@ void set_public_keys
 	}
 	else
 	{
-		std::cerr << _("GDBM ERROR") << ": " << gdbm_strerror(gdbm_errno) <<
-			std::endl;
+		std::cerr << _("GDBM ERROR") << ": " << gdbm_strerror(gdbm_errno) << std::endl;
 		perror("SecureSkat_pki::set_public_keys (gdbm_open)");
 		exit(-1);
 	}
@@ -374,6 +368,11 @@ void create_pki
 	(int &pki7771_port, int &pki7771_handle)
 {
 	pki7771_port = BindEmptyPort(7771);
+	if (pki7771_port < 0)
+	{
+		std::cerr << "SecureSkat_pki::create_pki: BindEmptyPort(7771) failed" << std::endl;
+		exit(-1);
+	}
 	if ((pki7771_handle = ListenToPort(pki7771_port)) < 0)
 		exit(-1);
 }
